//+------------------------------------------------------------------+
//|                                                     ScalpNet.mq4 |
//|                                Copyright  2009, Steven K. Brown |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Copyright  2009, Steven K. Brown"
#property link      ""

#property indicator_separate_window
#property indicator_buffers 8
#property indicator_color1 Lime
#property indicator_color2 Red
#property indicator_color3 Lime
#property indicator_color4 Red
#property indicator_color5 Lime
#property indicator_color6 Red
#property indicator_color7 Lime
#property indicator_color8 Red

#property indicator_maximum 5.0
#property indicator_minimum 0.0

//---- input parameters
extern int       MAPeriod1=55;
extern int       MAPeriod2=200;
extern double    SARStep=0.005;
extern double    SARMax=0.05;
extern int       FastEMA=12;
extern int       SlowEMA=26;
extern int       MACD_SMA=9;
//---- buffers
double MABuffer1_up[];
double MABuffer1_dn[];
double MABuffer2_up[];
double MABuffer2_dn[];
double SARBuffer_up[];
double SARBuffer_dn[];
double MACDBuffer_up[];
double MACDBuffer_dn[];

double MA1Val = 4.0;
double MA2Val = 3.0;
double SARVal = 2.0;
double MACDVal = 1.0;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
   SetIndexStyle(0,DRAW_ARROW);
   SetIndexArrow(0, 110);
   SetIndexLabel(0, "MA 1 Up");
   SetIndexBuffer(0,MABuffer1_up);
   SetIndexStyle(1,DRAW_ARROW);
   SetIndexArrow(1, 110);
   SetIndexLabel(1, "MA 1 Dn");
   SetIndexBuffer(1,MABuffer1_dn);

   SetIndexStyle(2,DRAW_ARROW);
   SetIndexArrow(2, 110);
   SetIndexLabel(2, "MA 2 Up");
   SetIndexBuffer(2,MABuffer2_up);
   SetIndexStyle(3,DRAW_ARROW);
   SetIndexArrow(3, 110);
   SetIndexLabel(3, "MA 2 Dn");
   SetIndexBuffer(3,MABuffer2_dn);

   SetIndexStyle(4,DRAW_ARROW);
   SetIndexArrow(4, 110);
   SetIndexLabel(4, "SAR Up");
   SetIndexBuffer(4,SARBuffer_up);
   SetIndexStyle(5,DRAW_ARROW);
   SetIndexArrow(5, 110);
   SetIndexLabel(5, "SAR Dn");
   SetIndexBuffer(5,SARBuffer_dn);

   SetIndexStyle(6,DRAW_ARROW);
   SetIndexArrow(6, 110);
   SetIndexLabel(6, "MACD Up");
   SetIndexBuffer(6,MACDBuffer_up);
   SetIndexStyle(7,DRAW_ARROW);
   SetIndexArrow(7, 110);
   SetIndexLabel(7, "MACD Dn");
   SetIndexBuffer(7,MACDBuffer_dn);

//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
    int limit;
    int counted_bars=IndicatorCounted();
    //---- check for possible errors
    if(counted_bars<0) return(-1);
    //---- the last counted bar will be recounted
    if(counted_bars>0) counted_bars--;
    limit=Bars-counted_bars;

    for (int iter = limit; iter >= 0; iter --)
    {
      double MA1_1 = iMA(NULL, 0, MAPeriod1, 0, MODE_EMA, PRICE_CLOSE, iter + 1);
      double MA1_2 = iMA(NULL, 0, MAPeriod2, 0, MODE_EMA, PRICE_CLOSE, iter + 1);
      double MA2_1 = iMA(NULL, 0, MAPeriod1, 0, MODE_EMA, PRICE_CLOSE, iter + 0);
      double MA2_2 = iMA(NULL, 0, MAPeriod2, 0, MODE_EMA, PRICE_CLOSE, iter + 0);
      double SAR_1 = iSAR(NULL, 0, SARStep, SARMax, iter + 1) * 100;
      double SAR_2 = iSAR(NULL, 0, SARStep, SARMax, iter + 0) * 100;
      double MACD_1 = iMACD(NULL, 0, FastEMA, SlowEMA, MACD_SMA, PRICE_CLOSE, MODE_SIGNAL, iter + 1);
      double MACD_2 = iMACD(NULL, 0, FastEMA, SlowEMA, MACD_SMA, PRICE_CLOSE, MODE_SIGNAL, iter + 0);

      //MA1Buffer[iter] = MA1_1 - MA1_2;
      //MA2Buffer[iter] = MA2_1 - MA2_2;
      //SARBuffer[iter] = SAR_1 - SAR_2;
      //MACDBuffer[iter] = MACD_1 - SAR_2;
      
      
      MABuffer1_up[iter] = EMPTY_VALUE;
      MABuffer1_dn[iter] = EMPTY_VALUE;
      MABuffer2_up[iter] = EMPTY_VALUE;
      MABuffer2_dn[iter] = EMPTY_VALUE;
      SARBuffer_up[iter] = EMPTY_VALUE;
      SARBuffer_dn[iter] = EMPTY_VALUE;
      MACDBuffer_up[iter] = EMPTY_VALUE;
      MACDBuffer_dn[iter] = EMPTY_VALUE;
      
      if (MA1_1 < MA1_2) MABuffer1_up[iter] = MA1Val;
      if (MA1_1 > MA1_2) MABuffer1_dn[iter] = MA1Val;
      
      if (MA2_1 > MA2_2) MABuffer2_up[iter] = MA2Val;
      if (MA2_1 < MA2_2) MABuffer2_dn[iter] = MA2Val;
      
      if (SAR_1 < SAR_2) SARBuffer_up[iter] = SARVal;
      if (SAR_1 > SAR_2) SARBuffer_dn[iter] = SARVal;
      
      if (MACD_1 < MACD_2) MACDBuffer_up[iter] = MACDVal;
      if (MACD_1 > MACD_2) MACDBuffer_dn[iter] = MACDVal;
    }
    return(0);
  }
  
//+------------------------------------------------------------------+